kedro — Kedro 0.17.6 documentation

# kedro

Description

Kedro is a framework that makes it easy to build robust and scalable data pipelines by providing uniform project templates, data abstraction, configuration and pipeline assembly.

Modules

`kedro.config` | `kedro.config` provides functionality for loading Kedro configuration from different file formats.
`kedro.extras` | `kedro.extras` provides functionality such as datasets and extensions.
`kedro.framework` | `kedro.framework` provides Kedro’s framework components
`kedro.io` | `kedro.io` provides functionality to read and write to a number of data sets.
`kedro.pipeline` | `kedro.pipeline` provides functionality to define and execute data-driven pipelines.
`kedro.runner` | `kedro.runner` provides runners that are able to execute `Pipeline` instances.
`kedro.utils` | This module provides a set of helper functions being used across different components of kedro package.
`kedro.versioning` | `kedro.versioning` provides functionality to setup the Journal for capturing information required to reproduce a Kedro run.